<?php
/*
Plugin Name: WooCommerce MX R1 račun
Plugin URI: http://media-x.hr
Description: Plugin za dodavanje polja za pravne osobe (R1 račun) u WooCommerceu
Version: 1.1
Author: Media X
Author URI: http://media-x.hr
License: GPLv3
*/

/**
 *  Let's enqueue our tiny script (toggle)
 */
add_action('wp_enqueue_scripts', 'enqueue_and_register_mx_script');

function enqueue_and_register_mx_script()
{

    wp_register_script('mx_oib_checkout_script', plugins_url('/includes/js/oib-form.js', __FILE__), array('jquery'));
    wp_enqueue_script('mx_oib_checkout_script');
}

add_action('woocommerce_after_checkout_validation', function($data, WP_Error &$errors) {
    if (isset($_POST['r1_checkbox']) && 1 == $_POST['r1_checkbox']) {
        $required = [
            'r1_ime_tvrtke' => 'Ime tvrtke',
            'r1_adresa_tvrtke' => 'Adresa tvrtke',
            'r1_postanski_broj_tvrtke' => 'Poštanski broj tvrtke',
            'r1_grad_tvrtke' => 'Grad tvrtke',
            'r1_oib_tvrtke' => 'OIB tvrtke',
        ];

        foreach ($required as $name => $label) {
            $value = isset($_POST[$name]) ? trim($_POST[$name]) : '';

            if (empty($value)) {
                $errors->add('required-field', sprintf('<strong>%s</strong> je obavezno polje.', $label));
            }
        }

        if (isset($_POST['r1_oib_tvrtke']) && !empty($_POST['r1_oib_tvrtke']) && !preg_match('/^\d{11}$/', $_POST['r1_oib_tvrtke'])) {
            $errors->add('oib', sprintf('<strong>OIB tvrtke</strong> je neispravnog formata.'));
        }
    }
}, 999, 2);

/**
 *  Remove "Company name" field from Billing section
 */
add_filter('woocommerce_checkout_fields', 'mx_company_override_checkout_fields');

function mx_company_override_checkout_fields($fields)
{
    unset($fields['billing']['billing_company']);

    return $fields;
}


/**
 * Add our new fields to the checkout
 */
add_action('woocommerce_after_checkout_billing_form', 'mx_custom_checkout_field');

function mx_custom_checkout_field($checkout)
{
    echo '<div id="mx_custom_checkout_field"><h3>' . __('Pravne osobe') . '</h3><p style="margin: 0 0 5px;">Trebate li R1 račun?</p>';

    woocommerce_form_field('r1_checkbox', array(
        'type' => 'checkbox',
        'class' => array('r1-checkbox form-row-wide'),
        'label' => __('Da'),
    ), $checkout->get_value('r1_checkbox'));

    woocommerce_form_field('r1_ime_tvrtke', array(
        'type' => 'text',
        'class' => array('r1-text form-row-wide'),
        'label' => __('Ime tvrtke'),
        'placeholder' => _x('Upišite ime tvrtke', 'placeholder', 'woocommerce'),
        'required' => true,
    ), $checkout->get_value('r1_ime_tvrtke'));

    woocommerce_form_field('r1_adresa_tvrtke', array(
        'type' => 'text',
        'class' => array('r1-text form-row-wide'),
        'label' => __('Adresa tvrtke'),
        'placeholder' => _x('Upišite adresu tvrtke', 'placeholder', 'woocommerce'),
        'required' => true,
    ), $checkout->get_value('r1_adresa_tvrtke'));

    woocommerce_form_field('r1_postanski_broj_tvrtke', array(
        'type' => 'text',
        'class' => array('r1-text form-row-first'),
        'label' => 'Poštanski broj',
        'placeholder' => 'Upišite poštanski broj',
        'required' => true,
    ), $checkout->get_value('r1_postanski_broj_tvrtke'));

    woocommerce_form_field('r1_grad_tvrtke', array(
        'type' => 'text',
        'class' => array('r1-text form-row-last'),
        'label' => 'Grad',
        'placeholder' => 'Upišite grad',
        'required' => true,
    ), $checkout->get_value('r1_grad_tvrtke'));

    woocommerce_form_field('r1_oib_tvrtke', array(
        'type' => 'text',
        'class' => array('r1-text form-row-wide'),
        'label' => __('OIB tvrtke'),
        'placeholder' => _x('Upišite OIB tvrtke', 'placeholder', 'woocommerce'),
        'required' => true,
    ), $checkout->get_value('r1_oib_tvrtke'));

    echo '</div>';

}


add_action('woocommerce_checkout_process', function() {
});

/**
 * Update the order meta with field value
 **/

add_action('woocommerce_checkout_update_order_meta', 'mx_oib_checkout_field_update_order_meta');

function mx_oib_checkout_field_update_order_meta($order_id)
{

    //check if $_POST has our custom fields
    if ($_POST['r1_checkbox']) {
        //If it does: update post meta for this order
        update_post_meta($order_id, 'R1 račun', esc_attr($_POST['r1_checkbox']));

        if ($_POST['r1_ime_tvrtke']) {
            update_post_meta($order_id, 'Ime tvrtke', esc_attr($_POST['r1_ime_tvrtke']));
        }
        if ($_POST['r1_adresa_tvrtke']) {
            update_post_meta($order_id, 'Adresa tvrtke', esc_attr($_POST['r1_adresa_tvrtke']));
        }
        if ($_POST['r1_oib_tvrtke']) {
            update_post_meta($order_id, 'OIB tvrtke', esc_attr($_POST['r1_oib_tvrtke']));
        }

        if ($_POST['r1_postanski_broj_tvrtke']) {
            update_post_meta($order_id, 'Poštanski broj tvrtke', esc_attr($_POST['r1_postanski_broj_tvrtke']));
        }

        if ($_POST['r1_grad_tvrtke']) {
            update_post_meta($order_id, 'Grad tvrtke', esc_attr($_POST['r1_grad_tvrtke']));
        }
    }

}

/**
 * Display fields values on the Order edit page
 */
add_action('woocommerce_admin_order_data_after_billing_address', 'mx_oib_checkout_field_display_admin_order_meta', 10, 1);

function mx_oib_checkout_field_display_admin_order_meta($order)
{

    $r1_checkbox = get_post_meta($order->id, 'R1 račun', true);
    if (!empty($r1_checkbox)) {

        echo '<h4>' . __('R1 račun') . '</h4>';
        echo '<p><strong>' . __('Ime tvrtke') . ':</strong> ' . get_post_meta($order->id, 'Ime tvrtke', true) . '</p>';
        echo '<p><strong>' . __('Adresa tvrke') . ':</strong> ' . get_post_meta($order->id, 'Adresa tvrtke', true) . '</p>';
        echo '<p><strong>' . __('OIB tvrtke') . ':</strong> ' . get_post_meta($order->id, 'OIB tvrtke', true) . '</p>';
    }
}

/**
 * Display fields values on the Order details page
 */
add_action('woocommerce_order_details_after_order_table', 'mx_oib_field_display_cust_order_meta', 10, 1);

function mx_oib_field_display_cust_order_meta($order)
{

    $r1_checkbox = get_post_meta($order->id, 'R1 račun', true);
    if (!empty($r1_checkbox)) {

        echo '<h2>' . __('Podaci za R1 račun') . '</h2>';
        echo '<p><strong>' . __('Ime tvrtke') . ':</strong> ' . get_post_meta($order->id, 'Ime tvrtke', true) . '</p>';
        echo '<p><strong>' . __('Adresa tvrke') . ':</strong> ' . get_post_meta($order->id, 'Adresa tvrtke', true) . '</p>';
        echo '<p><strong>' . __('OIB tvrtke') . ':</strong> ' . get_post_meta($order->id, 'OIB tvrtke', true) . '</p>';
    }
}

/**
 * Let's add the fields to order emails
 **/
add_filter('woocommerce_email_order_meta_keys', 'mx_woocommerce_email_order_meta_keys');

function mx_woocommerce_email_order_meta_keys($keys)
{

    if ($_POST['r1_checkbox']) {
        echo '<h2>R1 račun za kupca</h2>';

        $keys[] = 'Ime tvrtke';
        $keys[] = 'Adresa tvrtke';
        $keys[] = 'OIB tvrtke';

        return $keys;
    }
}

/**
 * Add the R1 column in order administration
 **/

add_filter('manage_edit-shop_order_columns', 'mx_r1_order_column', 20);
function mx_r1_order_column($columns)
{
    $offset = 9;
    $updated_columns = array_slice($columns, 0, $offset, true) +
        array('r1_checkbox' => esc_html__('R1 račun', 'woocommerce')) +
        array_slice($columns, $offset, NULL, true);
    return $updated_columns;
}

// Populate R1 column
add_action('manage_shop_order_posts_custom_column', 'mx_r1_order_column_values', 2);
function mx_r1_order_column_values($column)
{
    global $post;

    if ($column == 'r1_checkbox') {
        $r1_checkbox = get_post_meta($post->ID, 'R1 račun', true);
        if ($r1_checkbox > 0)
            print("Da");
        else print '-';
    }
}
